@@ -1,15 +1,12 @@
-# coding: utf-8
 """Test the config webservice API."""
 
 import json
 
-import requests
-
 from notebook.utils import url_path_join
 from notebook.tests.launchnotebook import NotebookTestBase
 
 
-class ConfigAPI(object):
+class ConfigAPI:
     """Wrapper for notebook API calls."""
     def __init__(self, request):
         self.request = request
